@@ -75,7 +75,7 @@ class ScssRenderer(object):
         if 'request' in system:
             request = system.get('request')
             request.response.content_type = 'text/css'
-            key = request.matchdict.get('css_path')
+            key = request.matchdict.get('stylesheet')
 
             if not self.options.get('cache', False) or key not in self.cache:
                 Logger.info('generating %s', key)
